@@ -34,6 +34,8 @@ class V8Context {
 
         SV* eval(const char* code, const char* file = 0);
 
+        SV* dispatch_function_in_event_loop(const char* func);
+
         SV* global_objects();
 
         int run_gc();
@@ -52,8 +54,8 @@ class V8Context {
         HV* stats;
         HV* msgs;
         long pagesize_bytes;
-        size_t max_allocated_bytes;  // unused for now
-        double max_timeout_us;       // unused for now
+        size_t max_allocated_bytes;  /* unused for now */
+        double max_timeout_us;       /* unused for now */
 
         static uint64_t GetTypeFlags(const Local<Value>& v);
     private:
